

Changelog
=========


Version 0.2.5
-------------

Released on 2022-01-15.

- Do not restrict requests and flask versions.
- Make it run on Python 3.10.


Version 0.2.4
-------------

Released on 2021-03-13.

- Move from Travis CI to GitHub Actions.
- Simplify packaging and deployment.


Version 0.2.3
-------------

Released on 2019-10-03.

- Make it possible to serve local mp4 files.
- Update dependencies.


Version 0.2.2
-------------

Released on 2019-05-02.

- Use raw.githubusercontent.com instead of cdn.jsdelivr.net to fetch markdown files.
- Update dependencies.


Version 0.2.1
-------------

Released on 2019-01-09.

- Clear fields if user/repo changes.
- Allow to toggle between remark and reveal.js.


Version 0.2.0
-------------

Released on 2018-12-09.

- Refactor customization of slides (uses ``*.css``, ``*.head.html``, and ``*.body.html``).
- Page title is not extracted from the markdown file.
- Allow to render using https://revealjs.com.
- v3 of the URL API becomes the default.


Version 0.1.0
-------------

Released on 2018-10-23.
